# This file is auto-generated, don't edit it. Thanks.
import time

from antchain_sdk_risk import models as risk_models
from alibabacloud_tea_util.client import Client as UtilClient
from Tea.exceptions import TeaException
from alibabacloud_tea_util import models as util_models
from Tea.request import TeaRequest
from Tea.core import TeaCore
from Tea.response import TeaResponse
from antchain_alipay_util.client import Client as AlipayUtilClient
from alibabacloud_rpc_util.client import Client as RPCUtilClient
from Tea.exceptions import UnretryableException


class Client:
    def __init__(self, config, _endpoint=None, _region_id=None, _access_key_id=None, _access_key_secret=None, _protocol=None, _user_agent=None, _read_timeout=None, _connect_timeout=None, _http_proxy=None, _https_proxy=None, _socks_5proxy=None, _socks_5net_work=None, _no_proxy=None, _max_idle_conns=None, _auth_token=None, _tenant=None, _workspace=None):
        """
        Init client with Config
        @param config: config contains the necessary information to create a client
        """
        self._endpoint = _endpoint
        self._region_id = _region_id
        self._access_key_id = _access_key_id
        self._access_key_secret = _access_key_secret
        self._protocol = _protocol
        self._user_agent = _user_agent
        self._read_timeout = _read_timeout
        self._connect_timeout = _connect_timeout
        self._http_proxy = _http_proxy
        self._https_proxy = _https_proxy
        self._socks_5proxy = _socks_5proxy
        self._socks_5net_work = _socks_5net_work
        self._no_proxy = _no_proxy
        self._max_idle_conns = _max_idle_conns
        self._auth_token = _auth_token
        self._tenant = _tenant
        self._workspace = _workspace
        if UtilClient.is_unset(config.to_map()):
            raise TeaException({
                "code": "ParameterMissing",
                "message": "'config' can not be unset"
            })
        self._access_key_id = config.access_key_id
        self._access_key_secret = config.access_key_secret
        self._tenant = config.tenant
        self._workspace = config.workspace
        self._endpoint = config.endpoint
        self._auth_token = config.auth_token
        self._protocol = config.protocol
        self._region_id = config.region_id
        self._user_agent = config.user_agent
        self._read_timeout = config.read_timeout
        self._connect_timeout = config.connect_timeout
        self._http_proxy = config.http_proxy
        self._https_proxy = config.https_proxy
        self._no_proxy = config.no_proxy
        self._socks_5proxy = config.socks_5proxy
        self._socks_5net_work = config.socks_5net_work
        self._max_idle_conns = config.max_idle_conns

    def do_request(self, action, protocol, method, pathname, request, runtime):
        """
        Encapsulate the request and invoke the network
        @param action: api name
        @param protocol: http or https
        @param method: e.g. GET
        @param pathname: pathname of every api
        @param request: which contains request params
        @param runtime: which controls some details of call api, such as retry times
        @return the response
        """
        runtime.validate()
        _runtime = {
            "timeouted": "retry",
            "readTimeout": UtilClient.default_number(runtime.read_timeout, self._read_timeout),
            "connectTimeout": UtilClient.default_number(runtime.connect_timeout, self._connect_timeout),
            "httpProxy": UtilClient.default_string(runtime.http_proxy, self._http_proxy),
            "httpsProxy": UtilClient.default_string(runtime.https_proxy, self._https_proxy),
            "noProxy": UtilClient.default_string(runtime.no_proxy, self._no_proxy),
            "maxIdleConns": UtilClient.default_number(runtime.max_idle_conns, self._max_idle_conns),
            "retry": {
                "retryable": runtime.autoretry,
                "maxAttempts": UtilClient.default_number(runtime.max_attempts, 3)
            },
            "backoff": {
                "policy": UtilClient.default_string(runtime.backoff_policy, "no"),
                "period": UtilClient.default_number(runtime.backoff_period, 1)
            },
            "ignoreSSL": runtime.ignore_ssl
        }
        _last_request = None
        _last_exception = None
        _now = time.time()
        _retry_times = 0
        while TeaCore.allow_retry(_runtime.get('retry'), _retry_times, _now):
            if _retry_times > 0:
                _backoff_time = TeaCore.get_backoff_time(_runtime.get('backoff'), _retry_times)
                if _backoff_time > 0:
                    TeaCore.sleep(_backoff_time)
            _retry_times = _retry_times + 1
            try:
                _request = TeaRequest()
                _request.protocol = UtilClient.default_string(self._protocol, protocol)
                _request.method = method
                _request.pathname = pathname
                _request.query = {
                    "method": action,
                    "version": "1.0",
                    "sign_type": "HmacSHA1",
                    "req_time": AlipayUtilClient.get_timestamp(),
                    "req_msg_id": UtilClient.get_nonce()
                }
                if not UtilClient.empty(self._tenant):
                    _request.query["tenant"] = self._tenant
                if not UtilClient.empty(self._workspace):
                    _request.query["workspace"] = self._workspace
                if not UtilClient.empty(self._auth_token):
                    _request.query["auth_token"] = self._auth_token
                else:
                    _request.query["access_key"] = self._access_key_id
                _request.headers = {
                    "host": self._endpoint,
                    "user-agent": self.get_user_agent()
                }
                tmp = UtilClient.anyify_map_value(RPCUtilClient.query(request))
                _request.body = UtilClient.to_form_string(tmp)
                _request.headers["content-type"] = "application/x-www-form-urlencoded"
                signed_param = TeaCore.merge(_request.query,
                    RPCUtilClient.query(request))
                _request.query["sign"] = AlipayUtilClient.get_signature(signed_param, self._access_key_secret)
                _last_request = _request
                _response = TeaCore.do_action(_request, _runtime)
                obj = UtilClient.read_as_json(_response.body)
                res = UtilClient.assert_as_map(obj)
                resp = UtilClient.assert_as_map(res.get('response'))
                if AlipayUtilClient.has_error(res):
                    raise TeaException({
                        "message": resp.get('result_msg'),
                        "data": resp,
                        "code": resp.get('result_code')
                    })
                return resp
            except Exception as e:
                if TeaCore.is_retryable(e):
                    _last_exception = e
                    continue
                raise e
        raise UnretryableException(_last_request, _last_exception)

    def get_user_agent(self):
        """
        Get user agent
        @return user agent
        """
        user_agent = UtilClient.get_user_agent(self._user_agent)
        return user_agent

    def add_bizpunish(self, request):
        """
        Description: 风控新增业务处罚API，用于新增业务处罚信息
        Summary: 风控新增业务处罚API
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.add_bizpunish_ex(request, runtime)

    def add_bizpunish_ex(self, request, runtime):
        """
        Description: 风控新增业务处罚API，用于新增业务处罚信息
        Summary: 风控新增业务处罚API
        """
        UtilClient.validate_model(request)
        return risk_models.AddBizpunishResponse().from_map(self.do_request("antcloud.riskcontrol.bizpunish.add", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def confirm_risk(self, request):
        """
        Description: 风险结果确认（后端进行doublecheck），用于业务执行前，业务方发起风险确认，判定对应的操作是否确实安全
        Summary: 风险结果确认
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.confirm_risk_ex(request, runtime)

    def confirm_risk_ex(self, request, runtime):
        """
        Description: 风险结果确认（后端进行doublecheck），用于业务执行前，业务方发起风险确认，判定对应的操作是否确实安全
        Summary: 风险结果确认
        """
        UtilClient.validate_model(request)
        return risk_models.ConfirmRiskResponse().from_map(self.do_request("antcloud.riskcontrol.risk.confirm", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def query_risk_switch(self, request):
        """
        Description: 查询风险事件的开关信息
        Summary: 查询风险事件的开关信息
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.query_risk_switch_ex(request, runtime)

    def query_risk_switch_ex(self, request, runtime):
        """
        Description: 查询风险事件的开关信息
        Summary: 查询风险事件的开关信息
        """
        UtilClient.validate_model(request)
        return risk_models.QueryRiskSwitchResponse().from_map(self.do_request("antcloud.riskcontrol.risk.switch.query", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def query_risk(self, request):
        """
        Description: 风险事件查询API，用于查询当前业务是否存在风险
        Summary: 风险事件查询API
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.query_risk_ex(request, runtime)

    def query_risk_ex(self, request, runtime):
        """
        Description: 风险事件查询API，用于查询当前业务是否存在风险
        Summary: 风险事件查询API
        """
        UtilClient.validate_model(request)
        return risk_models.QueryRiskResponse().from_map(self.do_request("antcloud.riskcontrol.risk.query", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def analyze_contentrisk(self, request):
        """
        Description: 内容风险分析API，用于分析当前内容是否存在风险
        Summary: 内容风险分析API
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.analyze_contentrisk_ex(request, runtime)

    def analyze_contentrisk_ex(self, request, runtime):
        """
        Description: 内容风险分析API，用于分析当前内容是否存在风险
        Summary: 内容风险分析API
        """
        UtilClient.validate_model(request)
        return risk_models.AnalyzeContentriskResponse().from_map(self.do_request("antcloud.riskcontrol.contentrisk.analyze", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def notify_risk(self, request):
        """
        Description: 业务处理完成后，将结果通知给风险
        Summary: 业务结果通知
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.notify_risk_ex(request, runtime)

    def notify_risk_ex(self, request, runtime):
        """
        Description: 业务处理完成后，将结果通知给风险
        Summary: 业务结果通知
        """
        UtilClient.validate_model(request)
        return risk_models.NotifyRiskResponse().from_map(self.do_request("antcloud.riskcontrol.risk.notify", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))


    def query_contentrisk_result(self, request):
        """
        Description: 内容风险分析结果查询API，用于风险分析结果的异步查询
        Summary: 内容风险分析结果查询API
        """
        runtime = util_models.RuntimeOptions(

        )
        return self.query_contentrisk_result_ex(request, runtime)

    def query_contentrisk_result_ex(self, request, runtime):
        """
        Description: 内容风险分析结果查询API，用于风险分析结果的异步查询
        Summary: 内容风险分析结果查询API
        """
        UtilClient.validate_model(request)
        return risk_models.QueryContentriskResultResponse().from_map(self.do_request("antcloud.riskcontrol.contentrisk.result.query", "HTTPS", "POST", "/gateway.do", request.to_map(), runtime))




# This file is auto-generated, don't edit it. Thanks.
from Tea.model import TeaModel

"""
Model for initing client
"""


class Config(TeaModel):
    def __init__(self, access_key_id=None, access_key_secret=None, auth_token=None, protocol=None, region_id=None, read_timeout=None, connect_timeout=None, http_proxy=None, https_proxy=None, endpoint=None, no_proxy=None, max_idle_conns=None, user_agent=None, socks_5proxy=None, socks_5net_work=None, tenant=None, workspace=None):
        self.access_key_id = access_key_id
        self.access_key_secret = access_key_secret
        self.auth_token = auth_token
        self.protocol = protocol
        self.region_id = region_id
        self.read_timeout = read_timeout
        self.connect_timeout = connect_timeout
        self.http_proxy = http_proxy
        self.https_proxy = https_proxy
        self.endpoint = endpoint
        self.no_proxy = no_proxy
        self.max_idle_conns = max_idle_conns
        self.user_agent = user_agent
        self.socks_5proxy = socks_5proxy
        self.socks_5net_work = socks_5net_work
        self.tenant = tenant
        self.workspace = workspace

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['accessKeyId'] = self.access_key_id
        result['accessKeySecret'] = self.access_key_secret
        result['authToken'] = self.auth_token
        result['protocol'] = self.protocol
        result['regionId'] = self.region_id
        result['readTimeout'] = self.read_timeout
        result['connectTimeout'] = self.connect_timeout
        result['httpProxy'] = self.http_proxy
        result['httpsProxy'] = self.https_proxy
        result['endpoint'] = self.endpoint
        result['noProxy'] = self.no_proxy
        result['maxIdleConns'] = self.max_idle_conns
        result['userAgent'] = self.user_agent
        result['socks5Proxy'] = self.socks_5proxy
        result['socks5NetWork'] = self.socks_5net_work
        result['tenant'] = self.tenant
        result['workspace'] = self.workspace
        return result

    def from_map(self, map={}):
        self.access_key_id = map.get('accessKeyId')
        self.access_key_secret = map.get('accessKeySecret')
        self.auth_token = map.get('authToken')
        self.protocol = map.get('protocol')
        self.region_id = map.get('regionId')
        self.read_timeout = map.get('readTimeout')
        self.connect_timeout = map.get('connectTimeout')
        self.http_proxy = map.get('httpProxy')
        self.https_proxy = map.get('httpsProxy')
        self.endpoint = map.get('endpoint')
        self.no_proxy = map.get('noProxy')
        self.max_idle_conns = map.get('maxIdleConns')
        self.user_agent = map.get('userAgent')
        self.socks_5proxy = map.get('socks5Proxy')
        self.socks_5net_work = map.get('socks5NetWork')
        self.tenant = map.get('tenant')
        self.workspace = map.get('workspace')
        return self


class RiskSwitchInfo(TeaModel):
    def __init__(self, biz_op=None, biz_tag=None, error_msg=None, group=None, id=None, sec_request_url=None, value=None):
        self.biz_op = biz_op
        self.biz_tag = biz_tag
        self.error_msg = error_msg
        self.group = group
        self.id = id
        self.sec_request_url = sec_request_url
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['biz_op'] = self.biz_op
        result['biz_tag'] = self.biz_tag
        result['error_msg'] = self.error_msg
        result['group'] = self.group
        result['id'] = self.id
        result['sec_request_url'] = self.sec_request_url
        result['value'] = self.value
        return result

    def from_map(self, map={}):
        self.biz_op = map.get('biz_op')
        self.biz_tag = map.get('biz_tag')
        self.error_msg = map.get('error_msg')
        self.group = map.get('group')
        self.id = map.get('id')
        self.sec_request_url = map.get('sec_request_url')
        self.value = map.get('value')
        return self


class ExtraParamInfo(TeaModel):
    def __init__(self, key=None, value=None):
        self.key = key
        self.value = value

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['key'] = self.key
        result['value'] = self.value
        return result

    def from_map(self, map={}):
        self.key = map.get('key')
        self.value = map.get('value')
        return self


class AddBizpunishRequest(TeaModel):
    def __init__(self, action_code=None, action_type=None, ext_params=None, instance_id=None, object_type=None, prod_code=None, reason=None, request_id=None, risk_level=None, src_request_id=None, tenant_id=None):
        self.action_code = action_code
        self.action_type = action_type
        self.ext_params = ext_params
        self.instance_id = instance_id
        self.object_type = object_type
        self.prod_code = prod_code
        self.reason = reason
        self.request_id = request_id
        self.risk_level = risk_level
        self.src_request_id = src_request_id
        self.tenant_id = tenant_id

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['action_code'] = self.action_code
        result['action_type'] = self.action_type
        result['ext_params'] = self.ext_params
        result['instance_id'] = self.instance_id
        result['object_type'] = self.object_type
        result['prod_code'] = self.prod_code
        result['reason'] = self.reason
        result['request_id'] = self.request_id
        result['risk_level'] = self.risk_level
        result['src_request_id'] = self.src_request_id
        result['tenant_id'] = self.tenant_id
        return result

    def from_map(self, map={}):
        self.action_code = map.get('action_code')
        self.action_type = map.get('action_type')
        self.ext_params = map.get('ext_params')
        self.instance_id = map.get('instance_id')
        self.object_type = map.get('object_type')
        self.prod_code = map.get('prod_code')
        self.reason = map.get('reason')
        self.request_id = map.get('request_id')
        self.risk_level = map.get('risk_level')
        self.src_request_id = map.get('src_request_id')
        self.tenant_id = map.get('tenant_id')
        return self


class AddBizpunishResponse(TeaModel):
    def __init__(self, action_result=None, request_id=None):
        self.action_result = action_result
        self.request_id = request_id

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['action_result'] = self.action_result
        result['request_id'] = self.request_id
        return result

    def from_map(self, map={}):
        self.action_result = map.get('action_result')
        self.request_id = map.get('request_id')
        return self


class ConfirmRiskRequest(TeaModel):
    def __init__(self, biz_op=None, biz_tag=None, ext_params=None, operator_id=None, security_id=None):
        self.biz_op = biz_op
        self.biz_tag = biz_tag
        self.ext_params = []
        self.operator_id = operator_id
        self.security_id = security_id

    def validate(self):
        if self.ext_params:
            for k in self.ext_params:
                if k :
                    k.validate()

    def to_map(self):
        result = {}
        result['biz_op'] = self.biz_op
        result['biz_tag'] = self.biz_tag
        result['ext_params'] = []
        if self.ext_params is not None:
            for k in self.ext_params:
                result['ext_params'].append(k.to_map() if k else None)
        else:
            result['ext_params'] = None
        result['operator_id'] = self.operator_id
        result['security_id'] = self.security_id
        return result

    def from_map(self, map={}):
        self.biz_op = map.get('biz_op')
        self.biz_tag = map.get('biz_tag')
        self.ext_params = []
        if map.get('ext_params') is not None:
            for k in map.get('ext_params'):
                temp_model = ExtraParamInfo()
                temp_model = temp_model.from_map(k)
                self.ext_params.append(temp_model)
        else:
            self.ext_params = None
        self.operator_id = map.get('operator_id')
        self.security_id = map.get('security_id')
        return self


class ConfirmRiskResponse(TeaModel):
    def __init__(self, confirm_success=None):
        self.confirm_success = confirm_success

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['confirm_success'] = self.confirm_success
        return result

    def from_map(self, map={}):
        self.confirm_success = map.get('confirm_success')
        return self


class QueryRiskSwitchRequest(TeaModel):
    def __init__(self, biz_op=None, biz_tag=None, group=None, sec_request_url=None):
        self.biz_op = biz_op
        self.biz_tag = biz_tag
        self.group = group
        self.sec_request_url = sec_request_url

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['biz_op'] = self.biz_op
        result['biz_tag'] = self.biz_tag
        result['group'] = self.group
        result['sec_request_url'] = self.sec_request_url
        return result

    def from_map(self, map={}):
        self.biz_op = map.get('biz_op')
        self.biz_tag = map.get('biz_tag')
        self.group = map.get('group')
        self.sec_request_url = map.get('sec_request_url')
        return self


class QueryRiskSwitchResponse(TeaModel):
    def __init__(self, risk_switch_info=None):
        self.risk_switch_info = []

    def validate(self):
        if self.risk_switch_info:
            for k in self.risk_switch_info:
                if k :
                    k.validate()

    def to_map(self):
        result = {}
        result['risk_switch_info'] = []
        if self.risk_switch_info is not None:
            for k in self.risk_switch_info:
                result['risk_switch_info'].append(k.to_map() if k else None)
        else:
            result['risk_switch_info'] = None
        return result

    def from_map(self, map={}):
        self.risk_switch_info = []
        if map.get('risk_switch_info') is not None:
            for k in map.get('risk_switch_info'):
                temp_model = RiskSwitchInfo()
                temp_model = temp_model.from_map(k)
                self.risk_switch_info.append(temp_model)
        else:
            self.risk_switch_info = None
        return self


class QueryRiskRequest(TeaModel):
    def __init__(self, biz_op=None, biz_tag=None, callback_url=None, client_ip=None, ext_params=None, login_name=None, operator_id=None, server_name=None, tenant=None, token_id=None, umid=None):
        self.biz_op = biz_op
        self.biz_tag = biz_tag
        self.callback_url = callback_url
        self.client_ip = client_ip
        self.ext_params = []
        self.login_name = login_name
        self.operator_id = operator_id
        self.server_name = server_name
        self.tenant = tenant
        self.token_id = token_id
        self.umid = umid

    def validate(self):
        if self.ext_params:
            for k in self.ext_params:
                if k :
                    k.validate()

    def to_map(self):
        result = {}
        result['biz_op'] = self.biz_op
        result['biz_tag'] = self.biz_tag
        result['callback_url'] = self.callback_url
        result['client_ip'] = self.client_ip
        result['ext_params'] = []
        if self.ext_params is not None:
            for k in self.ext_params:
                result['ext_params'].append(k.to_map() if k else None)
        else:
            result['ext_params'] = None
        result['login_name'] = self.login_name
        result['operator_id'] = self.operator_id
        result['server_name'] = self.server_name
        result['tenant'] = self.tenant
        result['token_id'] = self.token_id
        result['umid'] = self.umid
        return result

    def from_map(self, map={}):
        self.biz_op = map.get('biz_op')
        self.biz_tag = map.get('biz_tag')
        self.callback_url = map.get('callback_url')
        self.client_ip = map.get('client_ip')
        self.ext_params = []
        if map.get('ext_params') is not None:
            for k in map.get('ext_params'):
                temp_model = ExtraParamInfo()
                temp_model = temp_model.from_map(k)
                self.ext_params.append(temp_model)
        else:
            self.ext_params = None
        self.login_name = map.get('login_name')
        self.operator_id = map.get('operator_id')
        self.server_name = map.get('server_name')
        self.tenant = map.get('tenant')
        self.token_id = map.get('token_id')
        self.umid = map.get('umid')
        return self


class QueryRiskResponse(TeaModel):
    def __init__(self, security_id=None, sec_result=None, template_code=None, template_desc=None, verify_id=None, verify_url=None):
        self.security_id = security_id
        self.sec_result = sec_result
        self.template_code = template_code
        self.template_desc = template_desc
        self.verify_id = verify_id
        self.verify_url = verify_url

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['security_id'] = self.security_id
        result['sec_result'] = self.sec_result
        result['template_code'] = self.template_code
        result['template_desc'] = self.template_desc
        result['verify_id'] = self.verify_id
        result['verify_url'] = self.verify_url
        return result

    def from_map(self, map={}):
        self.security_id = map.get('security_id')
        self.sec_result = map.get('sec_result')
        self.template_code = map.get('template_code')
        self.template_desc = map.get('template_desc')
        self.verify_id = map.get('verify_id')
        self.verify_url = map.get('verify_url')
        return self


class AnalyzeContentriskRequest(TeaModel):
    def __init__(self, app_main_scene=None, app_main_scene_id=None, app_name=None, app_scene=None, app_scene_data_id=None, audio_urls=None, link_urls=None, operator_id=None, picture_urls=None, publish_date=None, tenant=None, text=None, video_urls=None):
        self.app_main_scene = app_main_scene
        self.app_main_scene_id = app_main_scene_id
        self.app_name = app_name
        self.app_scene = app_scene
        self.app_scene_data_id = app_scene_data_id
        self.audio_urls = []
        self.link_urls = []
        self.operator_id = operator_id
        self.picture_urls = []
        self.publish_date = publish_date
        self.tenant = tenant
        self.text = text
        self.video_urls = []

    def validate(self):
        if self.app_main_scene:
            self.validate_max_length(app_main_scene, 'app_main_scene', 0)
        if self.app_main_scene_id:
            self.validate_max_length(app_main_scene_id, 'app_main_scene_id', 0)
        if self.app_name:
            self.validate_max_length(app_name, 'app_name', 0)
        if self.app_scene:
            self.validate_max_length(app_scene, 'app_scene', 0)
        if self.app_scene_data_id:
            self.validate_max_length(app_scene_data_id, 'app_scene_data_id', 0)
        if self.publish_date:
            self.validate_pattern(publish_date, 'publish_date', '\\d{4}[-]\\d{1,2}[-]\\d{1,2}(\\s\\d{2}:\\d{2}(:\\d{2})?)?')
        if self.text:
            self.validate_max_length(text, 'text', 0)

    def to_map(self):
        result = {}
        result['app_main_scene'] = self.app_main_scene
        result['app_main_scene_id'] = self.app_main_scene_id
        result['app_name'] = self.app_name
        result['app_scene'] = self.app_scene
        result['app_scene_data_id'] = self.app_scene_data_id
        result['audio_urls'] = []
        if self.audio_urls is not None:
            for k in self.audio_urls:
                result['audio_urls'].append(k)
        else:
            result['audio_urls'] = None
        result['link_urls'] = []
        if self.link_urls is not None:
            for k in self.link_urls:
                result['link_urls'].append(k)
        else:
            result['link_urls'] = None
        result['operator_id'] = self.operator_id
        result['picture_urls'] = []
        if self.picture_urls is not None:
            for k in self.picture_urls:
                result['picture_urls'].append(k)
        else:
            result['picture_urls'] = None
        result['publish_date'] = self.publish_date
        result['tenant'] = self.tenant
        result['text'] = self.text
        result['video_urls'] = []
        if self.video_urls is not None:
            for k in self.video_urls:
                result['video_urls'].append(k)
        else:
            result['video_urls'] = None
        return result

    def from_map(self, map={}):
        self.app_main_scene = map.get('app_main_scene')
        self.app_main_scene_id = map.get('app_main_scene_id')
        self.app_name = map.get('app_name')
        self.app_scene = map.get('app_scene')
        self.app_scene_data_id = map.get('app_scene_data_id')
        self.audio_urls = []
        if map.get('audio_urls') is not None:
            for k in map.get('audio_urls'):
                self.audio_urls.append(k)
        else:
            self.audio_urls = None
        self.link_urls = []
        if map.get('link_urls') is not None:
            for k in map.get('link_urls'):
                self.link_urls.append(k)
        else:
            self.link_urls = None
        self.operator_id = map.get('operator_id')
        self.picture_urls = []
        if map.get('picture_urls') is not None:
            for k in map.get('picture_urls'):
                self.picture_urls.append(k)
        else:
            self.picture_urls = None
        self.publish_date = map.get('publish_date')
        self.tenant = map.get('tenant')
        self.text = map.get('text')
        self.video_urls = []
        if map.get('video_urls') is not None:
            for k in map.get('video_urls'):
                self.video_urls.append(k)
        else:
            self.video_urls = None
        return self


class AnalyzeContentriskResponse(TeaModel):
    def __init__(self, app_scene_data_id=None, event_id=None, need_query=None, reason=None, result_action=None):
        self.app_scene_data_id = app_scene_data_id
        self.event_id = event_id
        self.need_query = need_query
        self.reason = reason
        self.result_action = result_action

    def validate(self):
        if self.app_scene_data_id:
            self.validate_max_length(app_scene_data_id, 'app_scene_data_id', 0)
        if self.event_id:
            self.validate_max_length(event_id, 'event_id', 0)
        if self.need_query:
            self.validate_max_length(need_query, 'need_query', 0)
        if self.reason:
            self.validate_max_length(reason, 'reason', 0)
        if self.result_action:
            self.validate_max_length(result_action, 'result_action', 0)

    def to_map(self):
        result = {}
        result['app_scene_data_id'] = self.app_scene_data_id
        result['event_id'] = self.event_id
        result['need_query'] = self.need_query
        result['reason'] = self.reason
        result['result_action'] = self.result_action
        return result

    def from_map(self, map={}):
        self.app_scene_data_id = map.get('app_scene_data_id')
        self.event_id = map.get('event_id')
        self.need_query = map.get('need_query')
        self.reason = map.get('reason')
        self.result_action = map.get('result_action')
        return self


class NotifyRiskRequest(TeaModel):
    def __init__(self, biz_op=None, biz_result=None, biz_tag=None, ext_params=None, operator_id=None, security_id=None, tenant=None):
        self.biz_op = biz_op
        self.biz_result = biz_result
        self.biz_tag = biz_tag
        self.ext_params = []
        self.operator_id = operator_id
        self.security_id = security_id
        self.tenant = tenant

    def validate(self):
        if self.ext_params:
            for k in self.ext_params:
                if k :
                    k.validate()

    def to_map(self):
        result = {}
        result['biz_op'] = self.biz_op
        result['biz_result'] = self.biz_result
        result['biz_tag'] = self.biz_tag
        result['ext_params'] = []
        if self.ext_params is not None:
            for k in self.ext_params:
                result['ext_params'].append(k.to_map() if k else None)
        else:
            result['ext_params'] = None
        result['operator_id'] = self.operator_id
        result['security_id'] = self.security_id
        result['tenant'] = self.tenant
        return result

    def from_map(self, map={}):
        self.biz_op = map.get('biz_op')
        self.biz_result = map.get('biz_result')
        self.biz_tag = map.get('biz_tag')
        self.ext_params = []
        if map.get('ext_params') is not None:
            for k in map.get('ext_params'):
                temp_model = ExtraParamInfo()
                temp_model = temp_model.from_map(k)
                self.ext_params.append(temp_model)
        else:
            self.ext_params = None
        self.operator_id = map.get('operator_id')
        self.security_id = map.get('security_id')
        self.tenant = map.get('tenant')
        return self


class NotifyRiskResponse(TeaModel):
    def __init__(self):
        pass

    def validate(self):
        pass

    def to_map(self):
        result = {}
        return result

    def from_map(self, map={}):
        return self


class QueryContentriskResultRequest(TeaModel):
    def __init__(self, app_scene=None, app_scene_data_id=None, event_id=None):
        self.app_scene = app_scene
        self.app_scene_data_id = app_scene_data_id
        self.event_id = event_id

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['app_scene'] = self.app_scene
        result['app_scene_data_id'] = self.app_scene_data_id
        result['event_id'] = self.event_id
        return result

    def from_map(self, map={}):
        self.app_scene = map.get('app_scene')
        self.app_scene_data_id = map.get('app_scene_data_id')
        self.event_id = map.get('event_id')
        return self


class QueryContentriskResultResponse(TeaModel):
    def __init__(self, reason=None, result_action=None):
        self.reason = reason
        self.result_action = result_action

    def validate(self):
        pass

    def to_map(self):
        result = {}
        result['reason'] = self.reason
        result['result_action'] = self.result_action
        return result

    def from_map(self, map={}):
        self.reason = map.get('reason')
        self.result_action = map.get('result_action')
        return self
